A collection of data source definitions that can be used with the bowerbird package. These sources define a range of environmental and other data sources useful to Antarctic and Southern Ocean studies.
Author
Maintainer: Ben Raymond ben.raymond@aad.gov.au
Authors:
Ben Raymond ben.raymond@aad.gov.au
Michael Sumner
Charlene Guillaumot